#! /bin/bash
# This script will run when the pistore has detected an update is available and 
# initiated its own shutdown.

# Check we've got root.
if [ "$(whoami)" != "root" ]
	then
		echo "ERROR: You need root permissions to run this script."
		exit 1
fi

# Keep looping round until we determine that the pistore has shut itself down.
PID=`pidof "pistore"`
CYCLES=0
RESTART=0
# We might want to send some sort of signal to the pistore for it to shutdown.

while [ -n "$PID" ]
	do
	   RESTART=1
		kill $PID
		sleep 1
		PID=`pidof "pistore"`
		sleep 2
		
		# Increment our cycles count. We want to timeout after 10 failed checks (30s).
		CYCLES=$[CYCLES+1]

		if [ $CYCLES -ge 10 ]
			then
				echo "ERROR: pistore doesn't seem to be shutting down. Can't continue."
				exit 1
		fi
done



spinner()
{
    local pid=$1
    local delay=0.75
    local spinstr='|/-\'
    while [ "$(ps a | awk '{print $1}' | grep $pid)" ]; do
        local temp=${spinstr#?}
        printf " [%c]  " "$spinstr"
        local spinstr=$temp${spinstr%"$temp"}
        sleep $delay
        printf "\b\b\b\b\b\b"
    done
    printf "    \b\b\b\b"
}


echo -n "Updating apt-get package lists (this may take several minutes)..."
#sleep 30 &
apt-get update -qqd &
spinner $!

#apt-get update -qqd
apt-get update
#TODO display update whilst waiting for update - show update for now.

#apt-get -s install pistore
apt-get install pistore

echo "Update Complete."

# Restart the new pistore

if [ $RESTART -eq 1 ];
then
echo "restarting..."
sleep 3
pistore &
disown $!
fi

#maybe offer user interaction
#echo "Would you like to start  client now? (y/n)"
#read -s -n 1 KEY
#echo "typed in $KEY"
#if [ $KEY = "y" ];
#then
#echo "start client then"
#else
#echo "NO"
#fi
#indiecity-client



